.. include:: /_includes/wip_prolog.rst

:mod:`stix.exploit_target.vulnerability` Module
===============================================

.. module:: stix.exploit_target.vulnerability


Overview
--------
The :mod:`stix.exploit_target.vulnerability` module captures the software version and specific bug that causes an exploitable condition.


Classes
-------

.. autoclass:: Vulnerability
	:show-inheritance:
	:members:

.. autoclass:: CVSSVector
	:show-inheritance:
	:members:

.. autoclass:: AffectedSoftware
	:show-inheritance:
	:members:
